@@ -1,32 +1,37 @@
+from pprint import pprint
+
+from ffmpeg_streaming import FFProbe
 from .utiles import round_to_even
-from .streams import Streams
 from .rep import Representation
 
 
 def get_kilo_bit_rates(kilo_bit_rate, count):
     kilo_bites = []
+    divided_by = 1.5
 
     while count:
-        kilo_bit_rate = int(kilo_bit_rate/1.3)
-        kilo_bites.append(kilo_bit_rate)
+        k_bit_rate = int(kilo_bit_rate/divided_by)
+        kilo_bites.append(k_bit_rate)
+        divided_by += .5
         count -= 1
 
     return kilo_bites
 
 
 class AutoRepresentation:
-    def __init__(self, stream, heights):
-        if not isinstance(stream, Streams):
-            raise TypeError('The input must be instance of Streams')
-        self.video = stream.video()
+    def __init__(self, ffprobe, heights):
+        if not isinstance(ffprobe, FFProbe):
+            raise TypeError('The input must be instance of FFProbe')
+        self.format = ffprobe.format()
+        self.video = ffprobe.streams().video()
 
         if heights is None:
-            heights = [2160, 1080, 720, 480, 240, 144]
+            heights = [2160, 1080, 720, 480, 360, 240, 144]
         self.heights = heights
         
     def generate(self):
         width, height, ratio = self.dimension()
-        kilo_bitrate = round(int(self.video['bit_rate']) / 1024)
+        kilo_bitrate = self.kilo_bitrate()
 
         reps = [Representation(width=width, height=height, kilo_bitrate=kilo_bitrate)]
 
@@ -46,3 +51,12 @@ class AutoRepresentation:
         ratio = width / height
 
         return width, height, ratio
+
+    def kilo_bitrate(self):
+        try:
+            return round(int(self.video['bit_rate']) / 1024)
+        except KeyError:
+            try:
+                return round((int(self.format['bit_rate']) / 1024) * .9)
+            except KeyError:
+                raise KeyError('It could not determine the value of video bitrate')
